require 'json'

class JSONThermostat
  attr_accessor :current_value, :wanted_value, :range, :unit
  attr_accessor :set_airco, :set_heating

  def initialize(testjson)
    parsed        = JSON.parse(testjson)
    @wanted_value = parsed['temperature']
    @range        = parsed['range'] / 2.0
    @unitsetting  = parsed['unit']
  end

  def update(testjson)
    parsed           = JSON.parse(testjson)
    @current_value   = parsed['temperature']
    @unitmeasurement = parsed['unit']
    unit_controlsetting
    unit_controlmeasurement
    check
  end

  def check
    if @current_value < @wanted_value - @range
      heat
    elsif @current_value > @wanted_value + @range
      cool
    else
      normal
    end
  end

  def unit_controlsetting
    if @unitsetting == 'celsius'
    elsif @unitsetting == 'kelvin'
      @wanted_value = temp_from_kelvin(@wanted_value)
    elsif @unitsetting == 'fahrenheit'
      @wanted_value = temp_from_fahrenheit(@wanted_value)
      @range = range / 1.8
    end
  end

  def unit_controlmeasurement
    if @unitmeasurement == 'celsius'
    elsif @unitmeasurement == 'kelvin'
      @current_value = temp_from_kelvin(@current_value)
    elsif @unitmeasurement == 'fahrenheit'
      @current_value = temp_from_fahrenheit(@current_value)
    end
  end

  def temp_from_kelvin(value)
    value -= 273.2
    value
  end

  def temp_from_fahrenheit(value)
    value = (value - 32.0) / 1.8
    value
  end

  def cool
    JSON.generate(cooling: true, heating: false)
  end

  def heat
    JSON.generate(cooling: false, heating: true)
  end

  def normal
    JSON.generate(cooling: false, heating: false)
  end
end
